@@ -4,7 +4,7 @@
 /* Simple test to ensure that we can load the xapian module and exercise basic
  * functionality successfully.
  *
- * Copyright (C) 2004,2005,2006,2007,2009,2011,2012,2013,2014,2015,2016,2017 Olly Betts
+ * Copyright (C) 2004-2022 Olly Betts
  * Copyright (C) 2010 Richard Boulton
  *
  * This program is free software; you can redistribute it and/or
@@ -35,8 +35,6 @@ function die_on_error($errno, $errstr, $file, $line) {
 }
 set_error_handler("die_on_error", -1);
 
-include "xapian.php";
-
 # Test the version number reporting functions give plausible results.
 $v = Xapian::major_version().'.'.Xapian::minor_version().'.'.Xapian::revision();
 $v2 = Xapian::version_string();
@@ -48,7 +46,7 @@ if ($v != $v2) {
 $db = new XapianWritableDatabase('', Xapian::DB_BACKEND_INMEMORY);
 $db2 = new XapianWritableDatabase('', Xapian::DB_BACKEND_INMEMORY);
 
-# Check PHP5 handling of Xapian::DocNotFoundError
+# Check handling of Xapian::DocNotFoundError
 try {
     $doc2 = $db->get_document(2);
     print "Retrieved non-existent document\n";
@@ -201,9 +199,10 @@ if ($query3->get_description() != "Query((a OR b))") {
 }
 $enq = new XapianEnquire($db);
 
-// This ought to be wrapped as a constant, but this tests how it has been
-// wrapped for some time in PHP bindings, which we need to maintain for
-// compatibility with existing user code.
+// Check Xapian::BAD_VALUENO is wrapped suitably.
+$enq->set_collapse_key(Xapian::BAD_VALUENO);
+
+// Test that the non-constant wrapping prior to 1.4.10 still works.
 $enq->set_collapse_key(Xapian::BAD_VALUENO_get());
 
 $enq->set_query(new XapianQuery(XapianQuery::OP_OR, "there", "is"));
@@ -327,19 +326,53 @@ if ($query->get_description() !== 'Query(VALUE_RANGE 1 19991203 20011204)') {
 
 # Feature test for XapianFieldProcessor
 class testfieldprocessor extends XapianFieldProcessor {
+    static $count = 0;
+
+    function __construct() {
+        ++self::$count;
+        parent::__construct();
+    }
+
+    function __destruct() {
+        --self::$count;
+    }
+
     function apply($str) {
 	if ($str === 'spam') throw new Exception('already spam');
 	return new XapianQuery("spam");
     }
 }
 
-$tfp = new testfieldprocessor();
-$qp->add_prefix('spam', $tfp);
+$fp = new testfieldprocessor;
+if (testfieldprocessor::$count !== 1) {
+    print "testfieldprocessor counting not working\n";
+    exit(1);
+}
+{
+    # Check object is still usable after being assigned to an object that gets
+    # deleted.  The initial development version of PHP8 bindings failed to
+    # handle this case.
+    $qptmp = new XapianQueryParser;
+    $qptmp->add_prefix('spam', $fp);
+    unset($qptmp);
+}
+if (testfieldprocessor::$count === 0) {
+    print "testfieldprocessor object deleted early\n";
+    exit(1);
+}
+$qp->add_prefix('spam', $fp);
+unset($fp);
+$qp->add_boolean_prefix('filter', new testfieldprocessor);
 $query = $qp->parse_query('spam:ignored');
 if ($query->get_description() !== 'Query(spam)') {
     print "testfieldprocessor didn't work - result was ".$query->get_description()."\n";
     exit(1);
 }
+$query = $qp->parse_query('filter:ignored');
+if ($query->get_description() !== 'Query(0 * spam)') {
+    print "Boolean testfieldprocessor didn't work - result was ".$query->get_description()."\n";
+    exit(1);
+}
 
 try {
     $query = $qp->parse_query('spam:spam');
@@ -352,6 +385,15 @@ try {
     }
 }
 
+if (testfieldprocessor::$count === 0) {
+    print "testfieldprocessor deleted early\n";
+    exit(1);
+}
+unset($qp);
+if (testfieldprocessor::$count !== 0) {
+    print "testfieldprocessor object not deleted\n";
+}
+
 # Test setting and getting metadata
 if ($db->get_metadata('Foo') !== '') {
     print "Unexpected value for metadata associated with 'Foo' (expected ''): '".$db->get_metadata('Foo')."'\n";
@@ -458,12 +500,12 @@ $enquire->set_query(new XapianQuery("foo"));
 	exit(1);
     }
 
-    $mset = $enquire->get_mset(0, 10, 0, null, $md, null);
+    $mset = $enquire->get_mset(0, 10, 0, null, $md);
     mset_expect_order($mset, array(2));
 
     $md = new XapianValueSetMatchDecider(0, false);
     $md->add_value("ABC");
-    $mset = $enquire->get_mset(0, 10, 0, null, $md, null);
+    $mset = $enquire->get_mset(0, 10, 0, null, $md);
     mset_expect_order($mset, array(1, 3, 4, 5));
 }
 
@@ -537,6 +579,17 @@ if ($query->get_description() != 'Query()') {
 
 {
     class testspy extends XapianMatchSpy {
+        static $count = 0;
+
+        function __construct() {
+            ++self::$count;
+            parent::__construct();
+        }
+
+        function __destruct() {
+            --self::$count;
+        }
+
 	public $matchspy_count = 0;
 
 	function apply($doc, $wt) {
@@ -545,6 +598,10 @@ if ($query->get_description() != 'Query()') {
     }
 
     $matchspy = new testspy();
+    if (testspy::$count !== 1) {
+        print "testspy counting not working\n";
+        exit(1);
+    }
     $enquire->clear_matchspies();
     $enquire->add_matchspy($matchspy);
     $enquire->get_mset(0, 10);
@@ -552,6 +609,16 @@ if ($query->get_description() != 'Query()') {
 	print "Unexpected matchspy count of {$matchspy->matchspy_count}\n";
 	exit(1);
     }
+    unset($matchspy);
+    if (testspy::$count === 0) {
+        print "testspy object deleted early\n";
+        exit(1);
+    }
+    unset($enquire);
+    if (testspy::$count !== 0) {
+        print "testspy object not deleted\n";
+        exit(1);
+    }
 }
 
 # Regression test for SWIG bug - it was generating "return $r;" in wrapper
@@ -582,6 +649,16 @@ if ($s !== 'ask:1 i:1 in:2 nothing:1 return:2 tea:1 time:2 ') {
     exit(1);
 }
 
+// Test that XapianTermGenerator keeps a reference to XapianStopper.
+$indexer->set_stopper_strategy(XapianTermGenerator::STOP_ALL);
+{
+    $stop = new XapianSimpleStopper();
+    $stop->add('a');
+    $indexer->set_stopper($stop);
+    $stop = null;
+}
+$indexer->index_text("a b");
+
 # Test GeoSpatial API
 $coord = new XapianLatLongCoord();
 $coord = new XapianLatLongCoord(-41.288889, 174.777222);
@@ -607,6 +684,9 @@ $centre->append(new XapianLatLongCoord(40.6048, -74.4427));
 $ps = new XapianLatLongDistancePostingSource(COORD_SLOT, $centre, $metric, $range);
 $q = new XapianQuery("coffee");
 $q = new XapianQuery(XapianQuery::OP_AND, $q, new XapianQuery($ps));
+$q = new XapianQuery(XapianQuery::OP_OR, [$q, XapianQuery::MatchNothing()]);
+// Check that we keep a reference via XapianQuery.
+$ps = null;
 
 $enq = new XapianEnquire($db);
 $enq->set_query($q);
@@ -632,6 +712,8 @@ $qp = new XapianQueryParser();
     $stop = new XapianSimpleStopper();
     $stop->add('a');
     $qp->set_stopper($stop);
+    // Test that XapianQueryParser keeps a reference to XapianStopper.
+    $stop = null;
 }
 $query = $qp->parse_query('a b');
 if ($query->get_description() !== 'Query(b@2)') {
