@@ -1,7 +1,7 @@
 # Tests of Python-specific parts of the xapian bindings.
 #
 # Copyright (C) 2007 Lemur Consulting Ltd
-# Copyright (C) 2008,2009,2010,2011,2013,2014,2015,2016 Olly Betts
+# Copyright (C) 2008,2009,2010,2011,2013,2014,2015,2016,2019 Olly Betts
 # Copyright (C) 2010,2011 Richard Boulton
 #
 # This program is free software; you can redistribute it and/or
@@ -1759,6 +1759,17 @@ def test_repr():
     expect(repr(xapian.Database()) is None, False)
     expect(repr(xapian.WritableDatabase()) is None, False)
 
+def test_lone_surrogate():
+    # Test that a lone surrogate in input data raises UnicodeEncodeError.
+    # Regression test for bug fixed in 1.4.12 (previous versions quietly
+    # skipped the lone surrogate when converting to UTF-8).
+    noop_stemmer = xapian.Stem("none")
+    try:
+        term = noop_stemmer(u"a\udead0")
+        raise TestFail("Lone surrogate accepted (output as %s)" % term)
+    except UnicodeEncodeError:
+        pass
+
 result = True
 
 # Run all tests (ie, callables with names starting "test_").
