@@ -273,7 +273,7 @@ class XapianSmoketest < Test::Unit::TestCase
 
   def test_013_scaleweight
     query = Xapian::Query.new("foo")
-    query2 = Xapian::Query.new(Xapian::Query::OP_SCALE_WEIGHT, query, 5);
+    query2 = Xapian::Query.new(Xapian::Query::OP_SCALE_WEIGHT, query, 5)
     assert_equal(query2.description(), "Query(5 * foo)")
   end
 
@@ -302,18 +302,18 @@ class XapianSmoketest < Test::Unit::TestCase
     mset = enquire.mset(0, 10)
     assert_equal(mset.size(), 4)
     assert_equal(spy.values.map{|i| "%s:%d"%[i.term, i.termfreq]} * ",",
-		 "maybe:1,no:1,yes:2")
+                 "maybe:1,no:1,yes:2")
     assert_equal(spy.top_values(1).map{|i| "%s:%d"%[i.term, i.termfreq]} * ",",
-		 "yes:2")
+                 "yes:2")
     assert_equal(spy.top_values(2).map{|i| "%s:%d"%[i.term, i.termfreq]} * ",",
-		 "yes:2,maybe:1")
+                 "yes:2,maybe:1")
     assert_equal(spy.top_values(3).map{|i| "%s:%d"%[i.term, i.termfreq]} * ",",
-		 "yes:2,maybe:1,no:1")
+                 "yes:2,maybe:1,no:1")
 
     # Test the valuestream iterator, while we've got some data
     assert_equal(@db.valuestream(1).size(), 0)
     assert_equal(@db.valuestream(0).map{|i| "%d:%s"%[i.docid, i.value]}*",",
-		 "2:yes,3:yes,4:maybe,5:no")
+                 "2:yes,3:yes,4:maybe,5:no")
   end
 
   def test_016_compactor
@@ -367,7 +367,7 @@ class XapianSmoketest < Test::Unit::TestCase
     coords.append(Xapian::LatLongCoord.new(0, 0))
     assert_equal(coords.size(), 1)
     assert_equal(coords.all.map{|i| "%s"%i.description}*",",
-		 "Xapian::LatLongCoord(0, 0)")
+                 "Xapian::LatLongCoord(0, 0)")
     s = ''
     coords.all {|i| s += i.description }
     assert_equal(s, "Xapian::LatLongCoord(0, 0)")
@@ -381,7 +381,7 @@ class XapianSmoketest < Test::Unit::TestCase
 
         db = Xapian::WritableDatabase.new(dbpath, Xapian::DB_CREATE_OR_OVERWRITE)
         a = []
-        db.spellings { |x| a.append(x) }
+        db.spellings { |x| a.push(x) }
         assert_equal(a, db.spellings)
         assert_equal([], a)
         db.add_spelling("there")
@@ -389,7 +389,7 @@ class XapianSmoketest < Test::Unit::TestCase
         db.add_spelling("they're")
         db.add_spelling("there")
         a = []
-        db.spellings { |x| a.append(x) }
+        db.spellings { |x| a.push(x) }
         assert_equal(a, db.spellings)
         assert_equal([Xapian::Term.new("their", 0, 1),
                       Xapian::Term.new("there", 0, 2),
@@ -406,12 +406,12 @@ class XapianSmoketest < Test::Unit::TestCase
         db = Xapian::WritableDatabase.new(dbpath, Xapian::DB_CREATE_OR_OVERWRITE)
 
         k = []
-        db.synonym_keys { |x| k.append(x) }
+        db.synonym_keys { |x| k.push(x) }
         assert_equal(k, db.synonym_keys)
         assert_equal(k, [])
 
         a = []
-        db.synonyms('food') { |x| a.append(x) }
+        db.synonyms('food') { |x| a.push(x) }
         assert_equal(a, db.synonyms('food'))
         assert_equal(a, [])
 
@@ -422,22 +422,22 @@ class XapianSmoketest < Test::Unit::TestCase
         db.add_synonym("drink", "coffee")
 
         k = []
-        db.synonym_keys { |x| k.append(x) }
+        db.synonym_keys { |x| k.push(x) }
         assert_equal(k, db.synonym_keys)
         assert_equal(['drink', 'food'], k)
 
         a = []
-        db.synonyms('drink') { |x| a.append(x) }
+        db.synonyms('drink') { |x| a.push(x) }
         assert_equal(a, db.synonyms('drink'))
         assert_equal(['coffee', 'tea'], a)
 
         a = []
-        db.synonyms('food') { |x| a.append(x) }
+        db.synonyms('food') { |x| a.push(x) }
         assert_equal(a, db.synonyms('food'))
         assert_equal(['grub', 'kai', 'nosh'], a)
 
         a = []
-        db.synonyms('nothing') { |x| a.append(x) }
+        db.synonyms('nothing') { |x| a.push(x) }
         assert_equal(a, db.synonyms('nothing'))
         assert_equal([], a)
     }
@@ -454,17 +454,17 @@ class XapianSmoketest < Test::Unit::TestCase
     puts q.description
 
     a = []
-    qp.stoplist() { |x| a.append(x) }
+    qp.stoplist() { |x| a.push(x) }
     assert_equal(a, qp.stoplist())
     assert_equal(['the', 'a'], a)
 
     a = []
-    qp.unstem('Zthe') { |x| a.append(x) }
+    qp.unstem('Zthe') { |x| a.push(x) }
     assert_equal(a, qp.unstem('Zthe'))
     assert_equal([], a)
 
     a = []
-    qp.unstem('Zstart') { |x| a.append(x) }
+    qp.unstem('Zstart') { |x| a.push(x) }
     assert_equal(a, qp.unstem('Zstart'))
     assert_equal(['starting', 'started', 'start'], a)
   end
